@@ -4,6 +4,7 @@ from sanza.Crm.models import EntityType
 from django.conf import settings 
 from sanza.Crm import settings as crm_settings
 from django.core.urlresolvers import reverse, NoReverseMatch
+from datetime import datetime
 
 def crm(request):
     
@@ -21,4 +22,5 @@ def crm(request):
         'SANZA_ENTITY_TYPES': EntityType.objects.all(),
         'SANZA_MULTI_USER': getattr(settings, 'SANZA_MULTI_USER', True),
         'SANZA_EMAIL_LOGIN': ('sanza.Profile.backends.EmailModelBackend' in settings.AUTHENTICATION_BACKENDS),
+        'NOW': datetime.now()
     }
