@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import sys
 from django.conf import settings as project_settings
 
 ENTITY_LOGO_DIR = getattr(project_settings, 'ENTITY_LOGO_DIR', 'entities/logos')
@@ -15,5 +16,9 @@ ALLOW_SINGLE_CONTACT = getattr(project_settings, 'SANZA_ALLOW_SINGLE_CONTACT', T
 NO_ENTITY_TYPE = getattr(project_settings, 'SANZA_NO_ENTITY_TYPE', False)
 
 def is_unaccent_filter_supported():
+    if 'test' in sys.argv:
+        return False
     return getattr(project_settings, 'SANZA_UNACCENT_FILTER_SUPPORT', False)
 
+def city_formatters():
+    return getattr(project_settings, 'SANZA_CITY_FORMATTERS', ())
\ No newline at end of file
