@@ -19,6 +19,9 @@ SEARCH_FORMS = None
 from django.utils import importlib
 from itertools import chain
 from datetime import datetime
+from coop_cms.bs_forms import Form as BsForm, ModelForm as BsModelForm
+from django.template.loader import get_template
+from django.template import Context
 
 def load_from_name(constant_full_name):
     x = constant_full_name.split('.')
@@ -26,7 +29,7 @@ def load_from_name(constant_full_name):
     module = importlib.import_module(constant_path)
     return getattr(module, constant_name)
 
-class QuickSearchForm(forms.Form):
+class QuickSearchForm(BsForm):
     """Quick search form which is included in the menu"""
     text = forms.CharField(required=True,
         widget=forms.TextInput(attrs={'placeholder': _(u'Quick search')}))
@@ -48,8 +51,8 @@ def get_field_form(field):
 class GroupedSelect(forms.Select): 
     def render(self, name, value, attrs=None, choices=()):
         if value is None: value = '' 
-        final_attrs = self.build_attrs(attrs, name=name) 
-        output = [u'<select%s>' % flatatt(final_attrs)] 
+        final_attrs = self.build_attrs(attrs, name=name)
+        output = [u'<select {0}>'.format(flatatt(final_attrs))] 
         str_value = smart_unicode(value)
         for group_label, group in self.choices: 
             if group_label: # should belong to an optgroup
@@ -61,13 +64,13 @@ class GroupedSelect(forms.Select):
                 selected_html = (option_value == str_value) and u' selected="selected"' or ''
                 output.append(u'<option value="%s"%s>%s</option>' % (escape(option_value), selected_html, escape(option_label))) 
             if group_label:
-                output.append(u'</optgroup>') 
+                output.append(u'</optgroup>')
         output.append(u'</select>') 
         return u'\n'.join(output)
 
 class GroupedChoiceField(ChoiceField):
-    def __init__(self, choices=(), required=True, widget=GroupedSelect, label=None, initial=None, help_text=None):
-        super(ChoiceField, self).__init__(required, widget, label, initial, help_text)
+    def __init__(self, choices=(), required=True, widget=None, label=None, initial=None, help_text=None, *args, **kwargs):
+        super(ChoiceField, self).__init__(required, widget, label, initial, help_text, *args, **kwargs)
         self.choices = choices
         
     def clean(self, value):
@@ -92,12 +95,17 @@ class FieldChoiceForm(forms.Form):
     
     def __init__(self, *args, **kwargs):
         super(FieldChoiceForm, self).__init__(*args, **kwargs)
-        choices = [('', [('', _(u'Please select a filter'))])]#1st line is just a label and can't be selected
+        choices = [('', [('', '')])]#[('', [('', _(u'Please select a filter'))])]#1st line is just a label and can't be selected
         for (cat, fs) in get_search_forms():
             choices.append(
                 (cat, [(reverse('search_get_field', args=[f._name]), f._label) for f in fs if f])
             )
-        self.fields['field_choice'] = GroupedChoiceField(choices)
+        widget = GroupedSelect(attrs={
+            'class': 'form-control half-width',
+            'data-placeholder': _(u'Please select a filter'),
+        })
+        self.fields['field_choice'] = GroupedChoiceField(choices, widget=widget)
+       
         
     def as_it_is(self):
         "Returns this form rendered as HTML <p>s."
@@ -112,6 +120,14 @@ class SearchForm(forms.Form):
     name = forms.CharField(max_length=100, required=False,
         help_text=_('Enter a name and click save.'))
     
+    class Media:
+        css = {
+            'all': ('chosen/chosen.css', 'chosen/chosen-bootstrap.css')
+        }
+        js = (
+            'chosen/chosen.jquery.js',
+        )
+    
     excluded = forms.CharField(required=False, widget=forms.HiddenInput())
     #subject = forms.CharField(max_length=1000, required=False, widget=forms.HiddenInput())
     
@@ -261,10 +277,9 @@ class SearchForm(forms.Form):
         return list(contacts)
     
     def _get_filter_func(self):
-        #form_names = [f._name for f in chain.from_iterable(self._forms.values())]
-        #if 'main_contact' in form_names:
-        #    return lambda c: (not c.has_left)
-        #return lambda c: (not c.has_left) and c.main_contact
+        form_names = [f._name for f in chain.from_iterable(self._forms.values())]
+        if 'contact_has_left' in form_names:
+            return lambda c: c
         return lambda c: c and (not c.has_left)
 
     def get_contacts_by_entity(self):
@@ -320,11 +335,11 @@ class SearchForm(forms.Form):
         f = FieldChoiceForm()
         return u"""
             {0}
-            <a class="add-field" href="">{1}</a>
-            <a class="add-block" href="">{2}</a>
-            <a class="duplicate-block" href="">{5}</a>
-            <a class="clear-block" href="">{3}</a>
-            <a class="remove-block" href="">{4}</a>""".format(
+            <a class="btn btn-xs btn-default btn-yellow add-field" href=""><span class="glyphicon glyphicon-filter"></span> {1}</a>
+            <a class="btn btn-xs btn-default add-block" href=""><span class="glyphicon glyphicon-th-list"></span> {2}</a>
+            <a class="btn btn-xs btn-default duplicate-block" href=""><span class="glyphicon glyphicon-share"></span> {5}</a>
+            <a class="btn btn-xs btn-danger clear-block" href=""><span class="glyphicon glyphicon-remove"></span> {3}</a>
+            <a class="btn btn-xs btn-danger remove-block" href=""><span class="glyphicon glyphicon-trash"></span> {4}</a>""".format(
                 f.as_it_is(), _(u'Add filter'), _(u'Add block'), _(u'Clear'), _(u'Remove'), _(u'Duplicate'))
     
     def as_html(self):
@@ -339,7 +354,7 @@ class SearchForm(forms.Form):
                 html += '</div></div>'
         return html
 
-class SearchFieldForm(forms.Form):
+class SearchFieldForm(BsForm):
     def __init__(self, block, count, data=None, *args, **kwargs):
         self._block = block
         self._count = count
@@ -354,6 +369,10 @@ class SearchFieldForm(forms.Form):
         
     def _add_field(self, field):
         field.required = True
+        if not field.widget.attrs.get('class', None):
+            field.widget.attrs['class'] = "form-control"
+        else:
+            field.widget.attrs['class'] += " form-control"
         self.fields[self._get_field_name()] = field
         
     def clean(self):
@@ -363,13 +382,8 @@ class SearchFieldForm(forms.Form):
         return {self._name: self._value}
         
     def as_it_is(self):
-        "Returns this form rendered as HTML <p>s."
-        return self._html_output(
-            normal_row = u'<p%(html_class_attr)s>%(label)s %(field)s%(help_text)s <a href="" class="remove-field">{0}</a></p>'.format(_(u'Remove')),
-            error_row = u'%s',
-            row_ender = '</p>',
-            help_text_html = u' <span class="helptext">%s</span>',
-            errors_on_separate_row = True)
+        t = get_template("Search/_search_field_form.html")
+        return t.render(Context({"form": self}))
         
 class TwoDatesForm(SearchFieldForm):
     
@@ -544,3 +558,6 @@ class GroupForContactsForm(forms.Form):
     def get_contacts(self):
         ids = self.cleaned_data["contacts"].split(";")
         return Contact.objects.filter(id__in=ids)
+
+class SearchNameForm(forms.Form):
+    name = forms.CharField(required=True, label=_(u"Name"))
