@@ -2,19 +2,10 @@
 from sanza.Crm import search_forms, models, forms
 from django.utils.translation import ugettext as _
 from sanza.Crm import settings
+from sanza.Emailing import search_forms as emailing_search_forms
 
 SEARCH_FORMS = [
     (
-        _(u'Entity'),
-        [
-            search_forms.EntityNameSearchForm,
-            search_forms.EntityNameStartsWithSearchForm,
-            search_forms.TypeSearchForm if (not settings.NO_ENTITY_TYPE) else None,
-            search_forms.HasEntityForm if (settings.ALLOW_SINGLE_CONTACT) else None,
-            search_forms.RelationshipDateForm,
-            search_forms.EntityByModifiedDate,
-         ],
-    ),(
         _(u'Group'),
         [
             search_forms.GroupSearchForm,
@@ -31,10 +22,24 @@ SEARCH_FORMS = [
             search_forms.ZipCodeSearchForm,
             search_forms.HasZipCodeForm,
         ],
+    ),(
+        _(u'Entity'),
+        [
+            search_forms.EntityNameSearchForm,
+            search_forms.EntityNameStartsWithSearchForm,
+            search_forms.TypeSearchForm if (not settings.NO_ENTITY_TYPE) else None,
+            search_forms.HasEntityForm if (settings.ALLOW_SINGLE_CONTACT) else None,
+            search_forms.RelationshipDateForm,
+            search_forms.EntityByModifiedDate,
+            search_forms.EntityWithCustomField,
+            search_forms.EntityDescriptionForm,
+            search_forms.EntityNotesForm,
+         ],
     ),(
         _(u'Contacts'),
         [
             search_forms.ContactNameSearchForm,
+            search_forms.ContactFirstnameSearchForm,
             search_forms.ContactRoleSearchForm,
             search_forms.ContactByModifiedDate,
             search_forms.ContactNewsletterSearchForm,
@@ -43,6 +48,12 @@ SEARCH_FORMS = [
             search_forms.ContactAgeSearchForm,
             search_forms.ContactsRelationshipByType,
             search_forms.ContactsRelationshipByDate,
+            search_forms.ContactWithCustomField,
+            search_forms.ContactNotesSearchForm,
+            search_forms.ContactHasLeft,
+            search_forms.EmailSearchForm,
+            #search_forms.ContactNotesForm,
+            
             #search_forms.ContactOpportunityStatusSearchForm,
             #search_forms.ContactOpportunityNameSearchForm,
             #search_forms.ContactNoOpportunityWithNameSearchForm,
@@ -69,20 +80,26 @@ SEARCH_FORMS = [
     ),(
         _(u'Opportunities'),
         [
-            search_forms.OpportunityStatusSearchForm,
+            #search_forms.OpportunityStatusSearchForm,
             search_forms.OpportunitySearchForm,
-            search_forms.NotInOpportunitySearchForm,
+            #search_forms.NotInOpportunitySearchForm,
             #search_forms.OpportunityInProgressForm,
             search_forms.OpportunityNameSearchForm,
             #search_forms.OpportunityBetween,
             #search_forms.OpportunityByStartDate,
             #search_forms.OpportunityByEndDate,
-            search_forms.OpportunityTypeSearchForm,
-            search_forms.OpportunityReminderForm,
+            #search_forms.OpportunityTypeSearchForm,
+            #search_forms.OpportunityReminderForm,
             #search_forms.NoOpportunityWithNameSearchForm,
             #search_forms.NoOpportunityOfTypeSearchForm,
             #search_forms.NoOpportunityBetween,
         ],
+    ),(
+        _(u'Emailing'),
+        [
+            emailing_search_forms.EmailingSentSearchForm,
+            emailing_search_forms.EmailingOpenedSearchForm,
+        ],
     ),(
         _(u'Admin'),
         [
